package net.vtstar.zhongtong.avi.equipment.service;

import com.alibaba.excel.util.StringUtils;
import com.github.pagehelper.PageHelper;
import lombok.extern.slf4j.Slf4j;
import net.vtstar.scada.base.equipmgt.service.EquipDataService;
import net.vtstar.scada.base.gather.domain.EquipmentData;
import net.vtstar.user.mybatis.provider.Operation;
import net.vtstar.user.mybatis.provider.WhereFilter;
import net.vtstar.utils.DateUtils;
import net.vtstar.zhongtong.avi.equipment.mapper.EquipmentDataMapper;
import net.vtstar.zhongtong.avi.gateway.painting.domain.DryingRoomTempMachine;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;

/**
 * @Author: xiadongwei
 * @Date: 2019/9/20 9:31
 */
@Slf4j
@Service
public class DryingRoomTempService {

    @Autowired
    private EquipDataService equipDataService;

    @Autowired
    private EquipmentDataMapper dataMapper;

    /**
     * 查询温度状态列表
     */
    public List<EquipmentData> findPageEquip(Integer pageNum, Integer pageSize, String equipCode, Date beginTime) {
        PageHelper.startPage(pageNum, pageSize);
        if (null == beginTime){
            beginTime = new Date();
        }
        if (StringUtils.isEmpty(equipCode)){
            return equipDataService.findRunByType("DRYING_ROOM_TEMP");
        }
        String startOfDay = DateUtils.parseDateToString(DateUtils.getStartOfDay(0, beginTime), "yyyy-MM-dd HH:mm:ss");
        String endOfDay = DateUtils.parseDateToString(DateUtils.getEndOfDay(0, beginTime), "yyyy-MM-dd HH:mm:ss");
        return equipDataService.findRunByCodeAndDate2(equipCode, startOfDay, endOfDay);
    }


    public List<DryingRoomTempMachine> getTempByStateId(String equipCode, String beginTime, String endTime) {
        return dataMapper.findJoin(new WhereFilter() {{
            addFilter("eqp_code", Operation.EQUAL, equipCode);
            addFilter("create_time", Operation.EQUAL_GREATER_THAN, beginTime);
            addFilter("create_time", Operation.EQUAL_LESS_THAN, endTime);
        }}, DryingRoomTempMachine.class);
    }
}
