package net.vtstar.zhongtong.avi.gateway.painting.job;

import lombok.extern.slf4j.Slf4j;
import net.vtstar.scada.base.equipmgt.domain.Enum.EquipStatusEnum;
import net.vtstar.scada.base.gather.domain.EquipmentData;
import net.vtstar.scada.base.gather.job.GatherJob;
import net.vtstar.zhongtong.avi.gateway.painting.domain.SprayBoothStateMachine;
import org.quartz.JobExecutionContext;
import org.quartz.JobExecutionException;
import org.springframework.stereotype.Component;

import java.util.Date;

/**
 * 喷涂室状态数据采集JOB
 */
@Slf4j
@Component
public class SprayBoothStateMachineJob extends GatherJob {

    private static final String NAME = "SPRAY_BOOTH";

    @Override
    protected void executeInternal(JobExecutionContext context) throws JobExecutionException {

        log.info("JobName: {}", context.getJobDetail().getKey().getName());
        super.gatherByModbus(NAME, SprayBoothStateMachine.class);
    }

    @Override
    public boolean handleObject(EquipmentData equipmentData) {
        SprayBoothStateMachine data = (SprayBoothStateMachine) equipmentData;
        String state = data.getStatus();
        if (state != null && "0".equals(state)) {
            return false;
        }
        Integer runState = data.getState();
        if (null == runState){
            return false;
        }
        if (runState == 1){
            equipmentData.setEquipStatus(EquipStatusEnum.RUN);
        }else {
            equipmentData.setEquipStatus(EquipStatusEnum.SHUTDOWN);
        }
        return true;
    }

    @Override
    public Object handleValue(String fieldName, Object value) {
        if (null == value){
            return null;
        }
        Integer valueInt = Integer.valueOf(value.toString());
        return valueInt & 0x01;
    }

    @Override
    protected void postHandle(EquipmentData equipmentData) {
        ((SprayBoothStateMachine)equipmentData).setCreateTime(new Date());
    }
}
